@@ -10,11 +10,11 @@ config = {
         }
 
 def test_load_file():
-    args = _external_load(['twanager', '--load', 'test/test_external_load.py', 'foobar'])
+    args = _external_load(['twanager', '--load', 'test/test_external_load.py', 'foobar'], global_config)
     assert args == ['twanager', 'foobar']
     assert global_config['monkey'] == 'bar'
 
 def test_load_module():
-    args = _external_load(['twanager', '--load', 'test.test_external_load', 'foobar'])
+    args = _external_load(['twanager', '--load', 'test.test_external_load', 'foobar'], global_config)
     assert args == ['twanager', 'foobar']
     assert global_config['monkey'] == 'bar'
