@@ -174,14 +174,13 @@ class Store(StorageInterface):
             # read in the desired tiddler
             tiddler = self._read_tiddler_revision(tiddler)
             # now make another tiddler to get created time
-            # base_tiddler is the head of the revision stack
-            base_tiddler = Tiddler(tiddler.title)
-            base_tiddler.bag = tiddler.bag
-            base_tiddler = self._read_tiddler_revision(base_tiddler, index=-1)
-            # set created on new tiddler from modified on base_tiddler
+            first_rev = Tiddler(tiddler.title)
+            first_rev.bag = tiddler.bag
+            first_rev = self._read_tiddler_revision(first_rev, index=-1)
+            # set created on new tiddler from modified on first_rev
             # (might be the same)
-            tiddler.created = base_tiddler.modified
-            tiddler.creator = base_tiddler.modifier
+            tiddler.created = first_rev.modified
+            tiddler.creator = first_rev.modifier
             return tiddler
         except IOError, exc:
             raise NoTiddlerError('no tiddler for %s: %s' %
@@ -202,7 +201,7 @@ class Store(StorageInterface):
 
         locked = 0
         lock_attempts = 0
-        while (not locked):
+        while not locked:
             try:
                 lock_attempts = lock_attempts + 1
                 write_lock(tiddler_base_filename)
@@ -220,8 +219,11 @@ class Store(StorageInterface):
         tiddler_filename = self._tiddler_full_filename(tiddler, revision)
 
         self.serializer.object = tiddler
-        write_utf8_file(tiddler_filename, self.serializer.to_string())
+        representation = self.serializer.serialization.tiddler_as(tiddler,
+                omit_empty=True, omit_members=['creator'])
+        write_utf8_file(tiddler_filename, representation)
         write_unlock(tiddler_base_filename)
+
         tiddler.revision = revision
 
     def user_delete(self, user):
@@ -408,7 +410,7 @@ class Store(StorageInterface):
         """
         tiddler_string = read_utf8_file(tiddler_filename)
         self.serializer.object = tiddler
-        tiddler = self.serializer.from_string(tiddler_string)
+        self.serializer.from_string(tiddler_string)
         return tiddler
 
     def _read_tiddler_revision(self, tiddler, index=0):
